const bcrypt = require('bcrypt');
const pool = require('../db');

module.exports = {
    showLoginPage: (req, res) => {
        res.render('login', { message: req.flash('message') });
    },

    loginUser: async (req, res) => {
        const { email, rpassword } = req.body;

        // ตรวจสอบว่า email และรหัสผ่านถูกส่งมาหรือไม่
        if (!email || !rpassword) {
            req.flash('message', 'Please provide both email and password');
            return res.redirect('/login');
        }

        try {
            // ค้นหาผู้ใช้ในฐานข้อมูล
            const [rows] = await pool.execute('SELECT * FROM users WHERE email = ?', [email]);
            if (rows.length === 0) {
                req.flash('message', 'Email not found');
                return res.redirect('/login');
            }

            const user = rows[0];
            const match = await bcrypt.compare(rpassword, user.password);
            
            if (match) {
                // ถ้ารหัสผ่านถูกต้อง ให้บันทึก userId ใน session
                req.session.userId = user.user_id;
                res.redirect('/');
            } else {
                req.flash('message', 'Password incorrect');
                return res.redirect('/login');
            }
        } catch (err) {
            console.error(err);
            res.status(500).send('Server error');
        }
    }
};
