const bcrypt = require('bcrypt');
const pool = require('../db');

module.exports = {
    showRegisterPage: (req, res) => {
        res.render('register', { message: req.flash('message') });
    },

    registerUser: async (req, res) => {
        const { email, rpassword, confirm_password } = req.body;

        // ตรวจสอบข้อมูลที่จำเป็น
        if (!email || !rpassword || !confirm_password) {
            req.flash('message', 'กรุณากรอกข้อมูลให้ครบถ้วน');
            return res.redirect('/register');
        }

        // ตรวจสอบว่ารหัสผ่านทั้งสองตรงกันหรือไม่
        if (rpassword !== confirm_password) {
            req.flash('message', 'Passwords do not match!');
            return res.redirect('/register');
        }

        try {
            // ตรวจสอบว่าอีเมลมีอยู่ในระบบหรือไม่
            const [existingUser] = await pool.execute('SELECT * FROM users WHERE email = ?', [email]);
            if (existingUser.length > 0) {
                req.flash('message', 'Email is already registered.');
                return res.redirect('/register');
            }

            // แฮชรหัสผ่าน
            const hashedPassword = await bcrypt.hash(rpassword, 10);

            // บันทึกข้อมูลผู้ใช้ในฐานข้อมูล
            const query = 'INSERT INTO users (email, password) VALUES (?, ?)';
            const [result] = await pool.execute(query, [email, hashedPassword]);

            // ตรวจสอบว่ามีการบันทึกข้อมูลสำเร็จหรือไม่
            if (result.affectedRows > 0) {
                req.flash('message', 'Registration successful, please login.');
                res.redirect('/login');
            } else {
                req.flash('message', 'เกิดข้อผิดพลาดในการสมัครสมาชิก');
                res.redirect('/register');
            }

        } catch (err) {
            console.error('Error inserting user:', err);
            req.flash('message', 'เกิดข้อผิดพลาดในการสมัครสมาชิก');
            res.redirect('/register');
        }
    }
};
